/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<datamodel.h>)
#  include <datamodel.h>
#endif
#if __has_include(<datasource.h>)
#  include <datasource.h>
#endif
#if __has_include(<serviceoperationstatus.h>)
#  include <serviceoperationstatus.h>
#endif
#if __has_include(<types.h>)
#  include <types.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_plasma_plasma5support()
{
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<Plasma5Support::DataModel>("org.kde.plasma.plasma5support", 2);
    qmlRegisterTypesAndRevisions<Plasma5Support::DataSource>("org.kde.plasma.plasma5support", 2);
    qmlRegisterTypesAndRevisions<Plasma5Support::SortFilterModel>("org.kde.plasma.plasma5support", 2);
    qmlRegisterTypesAndRevisions<PropertyMapForeign>("org.kde.plasma.plasma5support", 2);
    QMetaType::fromType<QAbstractItemModel *>().id();
    qmlRegisterEnum<QAbstractItemModel::LayoutChangeHint>("QAbstractItemModel::LayoutChangeHint");
    qmlRegisterEnum<QAbstractItemModel::CheckIndexOption>("QAbstractItemModel::CheckIndexOption");
    QMetaType::fromType<QAbstractProxyModel *>().id();
    QMetaType::fromType<QSortFilterProxyModel *>().id();
    qmlRegisterTypesAndRevisions<ServiceOperationStatus>("org.kde.plasma.plasma5support", 2);
    qmlRegisterTypesAndRevisions<TypesForeign>("org.kde.plasma.plasma5support", 2);
    qmlRegisterEnum<Plasma5Support::Types::IntervalAlignment>("Plasma5Support::Types::IntervalAlignment");
    QT_WARNING_POP
    qmlRegisterModule("org.kde.plasma.plasma5support", 2, 0);
}

static const QQmlModuleRegistration orgkdeplasmaplasma5supportRegistration("org.kde.plasma.plasma5support", qml_register_types_org_kde_plasma_plasma5support);
