/****************************************************************************
** Meta object code from reading C++ file 'powermanagementengine.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../plasma5support-6.6.4/src/dataengines/powermanagement/powermanagementengine.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'powermanagementengine.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21PowermanagementEngineE_t {};
} // unnamed namespace

template <> constexpr inline auto PowermanagementEngine::qt_create_metaobjectdata<qt_meta_tag_ZN21PowermanagementEngineE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PowermanagementEngine",
        "updateBatteryChargeState",
        "",
        "newState",
        "udi",
        "updateBatteryPresentState",
        "updateBatteryChargePercent",
        "newValue",
        "updateBatteryEnergy",
        "updateBatteryPowerSupplyState",
        "updateAcPlugState",
        "onBattery",
        "updateBatteryNames",
        "updateOverallBattery",
        "deviceRemoved",
        "deviceAdded",
        "batteryRemainingTimeChanged",
        "time",
        "smoothedBatteryRemainingTimeChanged",
        "triggersLidActionChanged",
        "triggers",
        "hasInhibitionChanged",
        "inhibited",
        "inhibitionsChanged",
        "QList<InhibitionInfo>",
        "added",
        "removed",
        "chargeStopThresholdChanged",
        "threshold",
        "updatePowerProfileDaemonInstalled",
        "installed",
        "updatePowerProfileCurrentProfile",
        "profile",
        "updatePowerProfileChoices",
        "choices",
        "updatePowerProfilePerformanceInhibitedReason",
        "reason",
        "updatePowerProfilePerformanceDegradedReason",
        "updatePowerProfileHolds",
        "QList<QVariantMap>",
        "holds",
        "updatePowerProfileConfiguredProfile"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'updateBatteryChargeState'
        QtMocHelpers::SlotData<void(int, const QString &)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::QString, 4 },
        }}),
        // Slot 'updateBatteryPresentState'
        QtMocHelpers::SlotData<void(bool, const QString &)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 3 }, { QMetaType::QString, 4 },
        }}),
        // Slot 'updateBatteryChargePercent'
        QtMocHelpers::SlotData<void(int, const QString &)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 7 }, { QMetaType::QString, 4 },
        }}),
        // Slot 'updateBatteryEnergy'
        QtMocHelpers::SlotData<void(double, const QString &)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 7 }, { QMetaType::QString, 4 },
        }}),
        // Slot 'updateBatteryPowerSupplyState'
        QtMocHelpers::SlotData<void(bool, const QString &)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 3 }, { QMetaType::QString, 4 },
        }}),
        // Slot 'updateAcPlugState'
        QtMocHelpers::SlotData<void(bool)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'updateBatteryNames'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateOverallBattery'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'deviceRemoved'
        QtMocHelpers::SlotData<void(const QString &)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Slot 'deviceAdded'
        QtMocHelpers::SlotData<void(const QString &)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Slot 'batteryRemainingTimeChanged'
        QtMocHelpers::SlotData<void(qulonglong)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::ULongLong, 17 },
        }}),
        // Slot 'smoothedBatteryRemainingTimeChanged'
        QtMocHelpers::SlotData<void(qulonglong)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::ULongLong, 17 },
        }}),
        // Slot 'triggersLidActionChanged'
        QtMocHelpers::SlotData<void(bool)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 20 },
        }}),
        // Slot 'hasInhibitionChanged'
        QtMocHelpers::SlotData<void(bool)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 22 },
        }}),
        // Slot 'inhibitionsChanged'
        QtMocHelpers::SlotData<void(const QList<InhibitionInfo> &, const QStringList &)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 24, 25 }, { QMetaType::QStringList, 26 },
        }}),
        // Slot 'chargeStopThresholdChanged'
        QtMocHelpers::SlotData<void(int)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 28 },
        }}),
        // Slot 'updatePowerProfileDaemonInstalled'
        QtMocHelpers::SlotData<void(const bool &)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 30 },
        }}),
        // Slot 'updatePowerProfileCurrentProfile'
        QtMocHelpers::SlotData<void(const QString &)>(31, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 32 },
        }}),
        // Slot 'updatePowerProfileChoices'
        QtMocHelpers::SlotData<void(const QStringList &)>(33, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QStringList, 34 },
        }}),
        // Slot 'updatePowerProfilePerformanceInhibitedReason'
        QtMocHelpers::SlotData<void(const QString &)>(35, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 36 },
        }}),
        // Slot 'updatePowerProfilePerformanceDegradedReason'
        QtMocHelpers::SlotData<void(const QString &)>(37, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 36 },
        }}),
        // Slot 'updatePowerProfileHolds'
        QtMocHelpers::SlotData<void(const QList<QVariantMap> &)>(38, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 39, 40 },
        }}),
        // Slot 'updatePowerProfileConfiguredProfile'
        QtMocHelpers::SlotData<void(const QString &)>(41, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 32 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PowermanagementEngine, qt_meta_tag_ZN21PowermanagementEngineE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PowermanagementEngine::staticMetaObject = { {
    QMetaObject::SuperData::link<Plasma5Support::DataEngine::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21PowermanagementEngineE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21PowermanagementEngineE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21PowermanagementEngineE_t>.metaTypes,
    nullptr
} };

void PowermanagementEngine::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PowermanagementEngine *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->updateBatteryChargeState((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->updateBatteryPresentState((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 2: _t->updateBatteryChargePercent((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 3: _t->updateBatteryEnergy((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 4: _t->updateBatteryPowerSupplyState((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 5: _t->updateAcPlugState((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->updateBatteryNames(); break;
        case 7: _t->updateOverallBattery(); break;
        case 8: _t->deviceRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->deviceAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->batteryRemainingTimeChanged((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 11: _t->smoothedBatteryRemainingTimeChanged((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 12: _t->triggersLidActionChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->hasInhibitionChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->inhibitionsChanged((*reinterpret_cast<std::add_pointer_t<QList<InhibitionInfo>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 15: _t->chargeStopThresholdChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 16: _t->updatePowerProfileDaemonInstalled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 17: _t->updatePowerProfileCurrentProfile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 18: _t->updatePowerProfileChoices((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 19: _t->updatePowerProfilePerformanceInhibitedReason((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 20: _t->updatePowerProfilePerformanceDegradedReason((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 21: _t->updatePowerProfileHolds((*reinterpret_cast<std::add_pointer_t<QList<QVariantMap>>>(_a[1]))); break;
        case 22: _t->updatePowerProfileConfiguredProfile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *PowermanagementEngine::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PowermanagementEngine::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21PowermanagementEngineE_t>.strings))
        return static_cast<void*>(this);
    return Plasma5Support::DataEngine::qt_metacast(_clname);
}

int PowermanagementEngine::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Plasma5Support::DataEngine::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 23)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 23;
    }
    return _id;
}
QT_WARNING_POP
