/****************************************************************************
** Meta object code from reading C++ file 'datacontainer.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma5support-6.6.4/src/plasma5support/datacontainer.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'datacontainer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14Plasma5Support13DataContainerE_t {};
} // unnamed namespace

template <> constexpr inline auto Plasma5Support::DataContainer::qt_create_metaobjectdata<qt_meta_tag_ZN14Plasma5Support13DataContainerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Plasma5Support::DataContainer",
        "dataUpdated",
        "",
        "source",
        "Plasma5Support::DataEngine::Data",
        "data",
        "modelChanged",
        "QAbstractItemModel*",
        "model",
        "becameUnused",
        "updateRequested",
        "Plasma5Support::DataContainer*",
        "disconnectVisualization",
        "visualization",
        "forceImmediateUpdate",
        "timerEvent",
        "QTimerEvent*",
        "event",
        "storeJobFinished",
        "KJob*",
        "job",
        "populateFromStoredData",
        "retrieve"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'dataUpdated'
        QtMocHelpers::SignalData<void(const QString &, const Plasma5Support::DataEngine::Data &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { 0x80000000 | 4, 5 },
        }}),
        // Signal 'modelChanged'
        QtMocHelpers::SignalData<void(const QString &, QAbstractItemModel *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { 0x80000000 | 7, 8 },
        }}),
        // Signal 'becameUnused'
        QtMocHelpers::SignalData<void(const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'updateRequested'
        QtMocHelpers::SignalData<void(Plasma5Support::DataContainer *)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 3 },
        }}),
        // Slot 'disconnectVisualization'
        QtMocHelpers::SlotData<void(QObject *)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QObjectStar, 13 },
        }}),
        // Slot 'forceImmediateUpdate'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'timerEvent'
        QtMocHelpers::SlotData<void(QTimerEvent *)>(15, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Slot 'storeJobFinished'
        QtMocHelpers::SlotData<void(KJob *)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Slot 'populateFromStoredData'
        QtMocHelpers::SlotData<void(KJob *)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Slot 'retrieve'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DataContainer, qt_meta_tag_ZN14Plasma5Support13DataContainerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Plasma5Support::DataContainer::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14Plasma5Support13DataContainerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14Plasma5Support13DataContainerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14Plasma5Support13DataContainerE_t>.metaTypes,
    nullptr
} };

void Plasma5Support::DataContainer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DataContainer *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->dataUpdated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Plasma5Support::DataEngine::Data>>(_a[2]))); break;
        case 1: _t->modelChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QAbstractItemModel*>>(_a[2]))); break;
        case 2: _t->becameUnused((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->updateRequested((*reinterpret_cast<std::add_pointer_t<Plasma5Support::DataContainer*>>(_a[1]))); break;
        case 4: _t->disconnectVisualization((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 5: _t->forceImmediateUpdate(); break;
        case 6: _t->timerEvent((*reinterpret_cast<std::add_pointer_t<QTimerEvent*>>(_a[1]))); break;
        case 7: _t->d->storeJobFinished((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 8: _t->d->populateFromStoredData((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 9: _t->d->retrieve(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Plasma5Support::DataContainer* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DataContainer::*)(const QString & , const Plasma5Support::DataEngine::Data & )>(_a, &DataContainer::dataUpdated, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DataContainer::*)(const QString & , QAbstractItemModel * )>(_a, &DataContainer::modelChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DataContainer::*)(const QString & )>(_a, &DataContainer::becameUnused, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DataContainer::*)(Plasma5Support::DataContainer * )>(_a, &DataContainer::updateRequested, 3))
            return;
    }
}

const QMetaObject *Plasma5Support::DataContainer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Plasma5Support::DataContainer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14Plasma5Support13DataContainerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Plasma5Support::DataContainer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void Plasma5Support::DataContainer::dataUpdated(const QString & _t1, const Plasma5Support::DataEngine::Data & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void Plasma5Support::DataContainer::modelChanged(const QString & _t1, QAbstractItemModel * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void Plasma5Support::DataContainer::becameUnused(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Plasma5Support::DataContainer::updateRequested(Plasma5Support::DataContainer * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
