/****************************************************************************
** Meta object code from reading C++ file 'datamodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma5support-6.6.4/src/declarativeimports/datamodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'datamodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14Plasma5Support15SortFilterModelE_t {};
} // unnamed namespace

template <> constexpr inline auto Plasma5Support::SortFilterModel::qt_create_metaobjectdata<qt_meta_tag_ZN14Plasma5Support15SortFilterModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Plasma5Support::SortFilterModel",
        "QML.Element",
        "auto",
        "countChanged",
        "",
        "sortColumnChanged",
        "sourceModelChanged",
        "filterRegExpChanged",
        "filterStringChanged",
        "filterCallbackChanged",
        "QJSValue",
        "syncRoleNames",
        "get",
        "QVariantMap",
        "i",
        "mapRowToSource",
        "mapRowFromSource",
        "sourceModel",
        "QAbstractItemModel*",
        "filterRegExp",
        "filterString",
        "filterCallback",
        "filterRole",
        "sortRole",
        "sortOrder",
        "Qt::SortOrder",
        "sortColumn",
        "count"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'countChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sortColumnChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sourceModelChanged'
        QtMocHelpers::SignalData<void(QObject *)>(6, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QObjectStar, 4 },
        }}),
        // Signal 'filterRegExpChanged'
        QtMocHelpers::SignalData<void(const QString &)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'filterStringChanged'
        QtMocHelpers::RevisionedSignalData<void(const QString &)>(8, 4, QMC::AccessPublic, 0xff01, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'filterCallbackChanged'
        QtMocHelpers::RevisionedSignalData<void(const QJSValue &)>(9, 4, QMC::AccessPublic, 0xff01, QMetaType::Void, {{
            { 0x80000000 | 10, 4 },
        }}),
        // Slot 'syncRoleNames'
        QtMocHelpers::SlotData<void()>(11, 4, QMC::AccessProtected, QMetaType::Void),
        // Method 'get'
        QtMocHelpers::MethodData<QVariantMap(int) const>(12, 4, QMC::AccessPublic, 0x80000000 | 13, {{
            { QMetaType::Int, 14 },
        }}),
        // Method 'mapRowToSource'
        QtMocHelpers::MethodData<int(int) const>(15, 4, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 14 },
        }}),
        // Method 'mapRowFromSource'
        QtMocHelpers::MethodData<int(int) const>(16, 4, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 14 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'sourceModel'
        QtMocHelpers::PropertyData<QAbstractItemModel*>(17, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 2),
        // property 'filterRegExp'
        QtMocHelpers::PropertyData<QString>(19, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'filterString'
        QtMocHelpers::PropertyData<QString>(20, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4, 0xff01),
        // property 'filterCallback'
        QtMocHelpers::PropertyData<QJSValue>(21, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5, 0xff01),
        // property 'filterRole'
        QtMocHelpers::PropertyData<QString>(22, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'sortRole'
        QtMocHelpers::PropertyData<QString>(23, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'sortOrder'
        QtMocHelpers::PropertyData<Qt::SortOrder>(24, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'sortColumn'
        QtMocHelpers::PropertyData<int>(26, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'count'
        QtMocHelpers::PropertyData<int>(27, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<SortFilterModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Plasma5Support::SortFilterModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QSortFilterProxyModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14Plasma5Support15SortFilterModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14Plasma5Support15SortFilterModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14Plasma5Support15SortFilterModelE_t>.metaTypes,
    nullptr
} };

void Plasma5Support::SortFilterModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SortFilterModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->countChanged(); break;
        case 1: _t->sortColumnChanged(); break;
        case 2: _t->sourceModelChanged((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 3: _t->filterRegExpChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->filterStringChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->filterCallbackChanged((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1]))); break;
        case 6: _t->syncRoleNames(); break;
        case 7: { QVariantMap _r = _t->get((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 8: { int _r = _t->mapRowToSource((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 9: { int _r = _t->mapRowFromSource((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SortFilterModel::*)()>(_a, &SortFilterModel::countChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SortFilterModel::*)()>(_a, &SortFilterModel::sortColumnChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SortFilterModel::*)(QObject * )>(_a, &SortFilterModel::sourceModelChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SortFilterModel::*)(const QString & )>(_a, &SortFilterModel::filterRegExpChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (SortFilterModel::*)(const QString & )>(_a, &SortFilterModel::filterStringChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (SortFilterModel::*)(const QJSValue & )>(_a, &SortFilterModel::filterCallbackChanged, 5))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractItemModel* >(); break;
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QAbstractItemModel**>(_v) = _t->sourceModel(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->filterRegExp(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->filterString(); break;
        case 3: *reinterpret_cast<QJSValue*>(_v) = _t->filterCallback(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->filterRole(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->sortRole(); break;
        case 6: *reinterpret_cast<Qt::SortOrder*>(_v) = _t->sortOrder(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->sortColumn(); break;
        case 8: *reinterpret_cast<int*>(_v) = _t->count(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setModel(*reinterpret_cast<QAbstractItemModel**>(_v)); break;
        case 1: _t->setFilterRegExp(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setFilterString(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setFilterCallback(*reinterpret_cast<QJSValue*>(_v)); break;
        case 4: _t->setFilterRole(*reinterpret_cast<QString*>(_v)); break;
        case 5: _t->setSortRole(*reinterpret_cast<QString*>(_v)); break;
        case 6: _t->setSortOrder(*reinterpret_cast<Qt::SortOrder*>(_v)); break;
        case 7: _t->setSortColumn(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Plasma5Support::SortFilterModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Plasma5Support::SortFilterModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14Plasma5Support15SortFilterModelE_t>.strings))
        return static_cast<void*>(this);
    return QSortFilterProxyModel::qt_metacast(_clname);
}

int Plasma5Support::SortFilterModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QSortFilterProxyModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void Plasma5Support::SortFilterModel::countChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Plasma5Support::SortFilterModel::sortColumnChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Plasma5Support::SortFilterModel::sourceModelChanged(QObject * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Plasma5Support::SortFilterModel::filterRegExpChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Plasma5Support::SortFilterModel::filterStringChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Plasma5Support::SortFilterModel::filterCallbackChanged(const QJSValue & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN14Plasma5Support9DataModelE_t {};
} // unnamed namespace

template <> constexpr inline auto Plasma5Support::DataModel::qt_create_metaobjectdata<qt_meta_tag_ZN14Plasma5Support9DataModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Plasma5Support::DataModel",
        "QML.Element",
        "auto",
        "countChanged",
        "",
        "sourceModelChanged",
        "filterRegExpChanged",
        "dataUpdated",
        "sourceName",
        "QVariantMap",
        "data",
        "removeSource",
        "get",
        "i",
        "dataSource",
        "keyRoleFilter",
        "sourceFilter",
        "count"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'countChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sourceModelChanged'
        QtMocHelpers::SignalData<void(QObject *)>(5, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QObjectStar, 4 },
        }}),
        // Signal 'filterRegExpChanged'
        QtMocHelpers::SignalData<void(const QString &)>(6, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Slot 'dataUpdated'
        QtMocHelpers::SlotData<void(const QString &, const QVariantMap &)>(7, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 8 }, { 0x80000000 | 9, 10 },
        }}),
        // Slot 'removeSource'
        QtMocHelpers::SlotData<void(const QString &)>(11, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Method 'get'
        QtMocHelpers::MethodData<QVariantMap(int) const>(12, 4, QMC::AccessPublic, 0x80000000 | 9, {{
            { QMetaType::Int, 13 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'dataSource'
        QtMocHelpers::PropertyData<QObject*>(14, QMetaType::QObjectStar, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'keyRoleFilter'
        QtMocHelpers::PropertyData<QString>(15, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'sourceFilter'
        QtMocHelpers::PropertyData<QString>(16, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'count'
        QtMocHelpers::PropertyData<int>(17, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<DataModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Plasma5Support::DataModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractItemModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14Plasma5Support9DataModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14Plasma5Support9DataModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14Plasma5Support9DataModelE_t>.metaTypes,
    nullptr
} };

void Plasma5Support::DataModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DataModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->countChanged(); break;
        case 1: _t->sourceModelChanged((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 2: _t->filterRegExpChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->dataUpdated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2]))); break;
        case 4: _t->removeSource((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: { QVariantMap _r = _t->get((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DataModel::*)()>(_a, &DataModel::countChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DataModel::*)(QObject * )>(_a, &DataModel::sourceModelChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DataModel::*)(const QString & )>(_a, &DataModel::filterRegExpChanged, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QObject**>(_v) = _t->dataSource(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->keyRoleFilter(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->sourceFilter(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->count(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setDataSource(*reinterpret_cast<QObject**>(_v)); break;
        case 1: _t->setKeyRoleFilter(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setSourceFilter(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Plasma5Support::DataModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Plasma5Support::DataModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14Plasma5Support9DataModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractItemModel::qt_metacast(_clname);
}

int Plasma5Support::DataModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractItemModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void Plasma5Support::DataModel::countChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Plasma5Support::DataModel::sourceModelChanged(QObject * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Plasma5Support::DataModel::filterRegExpChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
