// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "geolocdebug.h"


Q_LOGGING_CATEGORY(DATAENGINE_GEOLOCATION, "org.kde.plasma.dataengine.geolocation", QtInfoMsg)

