/****************************************************************************
** Meta object code from reading C++ file 'dataengine.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma5support-6.6.4/src/plasma5support/dataengine.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dataengine.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14Plasma5Support10DataEngineE_t {};
} // unnamed namespace

template <> constexpr inline auto Plasma5Support::DataEngine::qt_create_metaobjectdata<qt_meta_tag_ZN14Plasma5Support10DataEngineE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Plasma5Support::DataEngine",
        "sourceAdded",
        "",
        "source",
        "sourceRemoved",
        "removeSource",
        "updateAllSources",
        "forceImmediateUpdateOfAllVisualizations",
        "internalUpdateSource",
        "DataContainer*",
        "sourceDestroyed",
        "object",
        "scheduleSourcesUpdated",
        "serviceForSource",
        "Plasma5Support::Service*",
        "connectSource",
        "visualization",
        "pollingInterval",
        "Plasma5Support::Types::IntervalAlignment",
        "intervalAlignment",
        "connectAllSources",
        "disconnectSource",
        "containerForSource",
        "Plasma5Support::DataContainer*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sourceAdded'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'sourceRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'removeSource'
        QtMocHelpers::SlotData<void(const QString &)>(5, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'updateAllSources'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'forceImmediateUpdateOfAllVisualizations'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'internalUpdateSource'
        QtMocHelpers::SlotData<void(DataContainer *)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 9, 3 },
        }}),
        // Slot 'sourceDestroyed'
        QtMocHelpers::SlotData<void(QObject *)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QObjectStar, 11 },
        }}),
        // Slot 'scheduleSourcesUpdated'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Method 'serviceForSource'
        QtMocHelpers::MethodData<Plasma5Support::Service *(const QString &)>(13, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { QMetaType::QString, 3 },
        }}),
        // Method 'connectSource'
        QtMocHelpers::MethodData<void(const QString &, QObject *, uint, Plasma5Support::Types::IntervalAlignment) const>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QObjectStar, 16 }, { QMetaType::UInt, 17 }, { 0x80000000 | 18, 19 },
        }}),
        // Method 'connectSource'
        QtMocHelpers::MethodData<void(const QString &, QObject *, uint) const>(15, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QObjectStar, 16 }, { QMetaType::UInt, 17 },
        }}),
        // Method 'connectSource'
        QtMocHelpers::MethodData<void(const QString &, QObject *) const>(15, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QObjectStar, 16 },
        }}),
        // Method 'connectAllSources'
        QtMocHelpers::MethodData<void(QObject *, uint, Plasma5Support::Types::IntervalAlignment) const>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QObjectStar, 16 }, { QMetaType::UInt, 17 }, { 0x80000000 | 18, 19 },
        }}),
        // Method 'connectAllSources'
        QtMocHelpers::MethodData<void(QObject *, uint) const>(20, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QObjectStar, 16 }, { QMetaType::UInt, 17 },
        }}),
        // Method 'connectAllSources'
        QtMocHelpers::MethodData<void(QObject *) const>(20, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QObjectStar, 16 },
        }}),
        // Method 'disconnectSource'
        QtMocHelpers::MethodData<void(const QString &, QObject *) const>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QObjectStar, 16 },
        }}),
        // Method 'containerForSource'
        QtMocHelpers::MethodData<Plasma5Support::DataContainer *(const QString &)>(22, 2, QMC::AccessPublic, 0x80000000 | 23, {{
            { QMetaType::QString, 3 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DataEngine, qt_meta_tag_ZN14Plasma5Support10DataEngineE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Plasma5Support::DataEngine::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14Plasma5Support10DataEngineE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14Plasma5Support10DataEngineE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14Plasma5Support10DataEngineE_t>.metaTypes,
    nullptr
} };

void Plasma5Support::DataEngine::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DataEngine *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sourceAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->sourceRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->removeSource((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->updateAllSources(); break;
        case 4: _t->forceImmediateUpdateOfAllVisualizations(); break;
        case 5: _t->d->internalUpdateSource((*reinterpret_cast<std::add_pointer_t<DataContainer*>>(_a[1]))); break;
        case 6: _t->d->sourceDestroyed((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 7: _t->d->scheduleSourcesUpdated(); break;
        case 8: { Plasma5Support::Service* _r = _t->serviceForSource((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Plasma5Support::Service**>(_a[0]) = std::move(_r); }  break;
        case 9: _t->connectSource((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<Plasma5Support::Types::IntervalAlignment>>(_a[4]))); break;
        case 10: _t->connectSource((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[3]))); break;
        case 11: _t->connectSource((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[2]))); break;
        case 12: _t->connectAllSources((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Plasma5Support::Types::IntervalAlignment>>(_a[3]))); break;
        case 13: _t->connectAllSources((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2]))); break;
        case 14: _t->connectAllSources((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 15: _t->disconnectSource((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[2]))); break;
        case 16: { Plasma5Support::DataContainer* _r = _t->containerForSource((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Plasma5Support::DataContainer**>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DataEngine::*)(const QString & )>(_a, &DataEngine::sourceAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DataEngine::*)(const QString & )>(_a, &DataEngine::sourceRemoved, 1))
            return;
    }
}

const QMetaObject *Plasma5Support::DataEngine::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Plasma5Support::DataEngine::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14Plasma5Support10DataEngineE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Plasma5Support::DataEngine::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 17;
    }
    return _id;
}

// SIGNAL 0
void Plasma5Support::DataEngine::sourceAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Plasma5Support::DataEngine::sourceRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
